==> spincast-plugins-routing-0.9.14-sources.jar: org/spincast/plugins/routing/SpincastRoutingRequestContextAddon.java <==
package org.spincast.plugins.routing;

import org.spincast.core.config.SpincastConstants;
import org.spincast.core.exchange.IRequestContext;
import org.spincast.core.routing.IRouteHandlerMatch;
import org.spincast.core.routing.IRoutingRequestContextAddon;
import org.spincast.core.routing.IRoutingResult;

import com.google.inject.Inject;

public class SpincastRoutingRequestContextAddon<R extends IRequestContext<R>>
                                               implements IRoutingRequestContextAddon<R> {

    private final R requestContext;

    @Inject
    public SpincastRoutingRequestContextAddon(R requestContext) {
        this.requestContext = requestContext;
    }

    protected R getRequestContext() {
        return this.requestContext;
    }

    protected IRouteHandlerMatch<R> getCurrentRouteMatch() {

        @SuppressWarnings("unchecked")
        IRouteHandlerMatch<R> match =
                (IRouteHandlerMatch<R>)getRequestContext().variables()
                                                          .get(SpincastConstants.RequestScopedVariables.ROUTE_HANDLER_MATCH);
        return match;
    }

    @Override
    public int getPosition() {
        return getCurrentRouteMatch().getPosition();
    }

    @Override
    public IRouteHandlerMatch<R> getCurrentRouteHandlerMatch() {
        return getCurrentRouteMatch();
    }

    @Override
    public IRoutingResult<R> getRoutingResult() {

        @SuppressWarnings("unchecked")
        IRoutingResult<R> routingResult =
                (IRoutingResult<R>)getRequestContext().variables()
                                                      .get(SpincastConstants.RequestScopedVariables.ROUTING_RESULT);
        return routingResult;
    }

    @Override
    public boolean isNotFoundRoute() {
        Boolean isNotFoundRoute =
                getRequestContext().variables().get(SpincastConstants.RequestScopedVariables.IS_NOT_FOUND_ROUTE,
                                                    Boolean.class);
        return isNotFoundRoute != null && isNotFoundRoute;
    }

    @Override
    public boolean isExceptionRoute() {
        Boolean isExceptionHandling =
                getRequestContext().variables().get(SpincastConstants.RequestScopedVariables.IS_EXCEPTION_HANDLING,
                                                    Boolean.class);
        return isExceptionHandling != null && isExceptionHandling;
    }

    @Override
    public boolean isForwarded() {

        String forwardedUrl =
                getRequestContext().variables().getAsString(SpincastConstants.RequestScopedVariables.FORWARD_ROUTE_URL);
        return forwardedUrl != null;
    }

}

==> spincast-plugins-routing-0.9.50-sources.jar: org/spincast/plugins/routing/SpincastRoutingRequestContextAddon.java <==
package org.spincast.plugins.routing;

import org.spincast.core.config.SpincastConstants;
import org.spincast.core.exchange.RequestContext;
import org.spincast.core.routing.RouteHandlerMatch;
import org.spincast.core.routing.RoutingRequestContextAddon;
import org.spincast.core.routing.RoutingResult;

import com.google.inject.Inject;

public class SpincastRoutingRequestContextAddon<R extends RequestContext<R>>
                                               implements RoutingRequestContextAddon<R> {

    private final R requestContext;

    @Inject
    public SpincastRoutingRequestContextAddon(R requestContext) {
        this.requestContext = requestContext;
    }

    protected R getRequestContext() {
        return this.requestContext;
    }

    protected RouteHandlerMatch<R> getCurrentRouteMatch() {

        @SuppressWarnings("unchecked")
        RouteHandlerMatch<R> match =
                (RouteHandlerMatch<R>)getRequestContext().variables()
                                                         .get(SpincastConstants.RequestScopedVariables.ROUTE_HANDLER_MATCH);
        return match;
    }

    @Override
    public int getPosition() {
        return getCurrentRouteMatch().getPosition();
    }

    @Override
    public RouteHandlerMatch<R> getCurrentRouteHandlerMatch() {
        return getCurrentRouteMatch();
    }

    @Override
    public RoutingResult<R> getRoutingResult() {

        @SuppressWarnings("unchecked")
        RoutingResult<R> routingResult =
                (RoutingResult<R>)getRequestContext().variables()
                                                     .get(SpincastConstants.RequestScopedVariables.ROUTING_RESULT);
        return routingResult;
    }

    @Override
    public boolean isNotFoundRoute() {
        Boolean isNotFoundRoute =
                getRequestContext().variables().get(SpincastConstants.RequestScopedVariables.IS_NOT_FOUND_ROUTE,
                                                    Boolean.class);
        return isNotFoundRoute != null && isNotFoundRoute;
    }

    @Override
    public boolean isExceptionRoute() {
        Boolean isExceptionHandling =
                getRequestContext().variables().get(SpincastConstants.RequestScopedVariables.IS_EXCEPTION_HANDLING,
                                                    Boolean.class);
        return isExceptionHandling != null && isExceptionHandling;
    }

    @Override
    public boolean isForwarded() {

        String forwardedUrl =
                getRequestContext().variables().getAsString(SpincastConstants.RequestScopedVariables.FORWARD_ROUTE_URL);
        return forwardedUrl != null;
    }

}
